pub enum Error {
KeyAlreadyExists,
KeyNotFound,
RequestTimeout,
ReceiverDropped,
Canceled,
}Variants
KeyAlreadyExists
A request with the same key is already pending.
KeyNotFound
No pending request was found for the given key.
RequestTimeout
The request was not answered within its timeout.
ReceiverDropped
The waiter was dropped before a response could be delivered.
Canceled
The pending request was canceled (explicitly or because the
owning PendingRequests was dropped) before a response arrived.