pub struct ResponseWaiter<K: Eq + Hash, R> { /* private fields */ }Expand description
A future that resolves with the response for a single request.
Resolves to:
Ok(response)whenPendingRequests::handle_responsedelivers a value,Err(Error::RequestTimeout)when the configured timeout elapses first,Err(Error::Canceled)when the request is canceled or the registry is dropped.